We are working on the vscode atopile extension.

Relevant directories:
src/vscode-atopile: Extension specific code, Primarily hosts webviews and bootstraps the backend
src/ui-server: React components that make up the actual UI
projects/atopile/src/atopile/server: Backend responsible for running builds, installing packages etc.

src/vscode-atopile/ui-todo.md: Todo list of tasks related to the UI, read only.

Can you look at  